#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadRandom
version:              0.5.3
visibility:           public
id:                   MonadRandom-0.5.3-6FKVZ4mCBKz2d1OcVIEmNj
key:                  MonadRandom-0.5.3-6FKVZ4mCBKz2d1OcVIEmNj
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  217657f4ee387a6ec4902741af972941
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-8.10.5/site-local/MonadRandom-0.5.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/MonadRandom-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/MonadRandom-0.5.3
hs-libraries:         HSMonadRandom-0.5.3-6FKVZ4mCBKz2d1OcVIEmNj
depends:
    base-4.14.2.0 mtl-2.2.2 primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

